package com.fastbee.ggroup.service.impl;

import java.util.List;
import com.fastbee.common.utils.DateUtils;
import com.fastbee.ggroup.domain.GSiteGroups;
import com.fastbee.ggroup.domain.dto.GGroupSiteDto;
import com.fastbee.ggroup.mapper.GSiteGroupsMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.ggroup.mapper.GSitesMapper;
import com.fastbee.ggroup.domain.GSites;
import com.fastbee.ggroup.service.IGSitesService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 站点Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-09-29
 */
@Service
public class GSitesServiceImpl implements IGSitesService 
{
    @Autowired
    private GSitesMapper gSitesMapper;

    @Autowired
    private GSiteGroupsMapper gSiteGroupsMapper;

    /**
     * 查询站点
     * 
     * @param id 站点主键
     * @return 站点
     */
    @Override
    public GSites selectGSitesById(Long id)
    {
        return gSitesMapper.selectGSitesById(id);
    }

    /**
     * 查询站点列表
     * 
     * @param gSites 站点
     * @return 站点
     */
    @Override
    public List<GSites> selectGSitesList(GSites gSites)
    {
        return gSitesMapper.selectGSitesList(gSites);
    }

    /**
     * 新增站点
     * 
     * @param gGroupSiteDto 站点
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertGSites(GGroupSiteDto gGroupSiteDto)
    {   //更新关系表
        GSites gSites = new GSites();
        gSites.setName(gGroupSiteDto.getName());
        gSites.setType(gGroupSiteDto.getType());
        gSites.setIcon(gGroupSiteDto.getIcon());

        int inserted = gSitesMapper.insert(gSites);
        gGroupSiteDto.setSiteId(gSites.getId());
        int inserted1 = gSitesMapper.insertGSites(gGroupSiteDto);
        return inserted==1&&inserted1==1?1:0 ;
    }

    /**
     * 修改站点
     * 
     * @param gSites 站点
     * @return 结果
     */
    @Override
    public int updateGSites(GSites gSites)
    {
        gSites.setUpdateTime(DateUtils.getNowDate());
        return gSitesMapper.updateById(gSites);
    }

    /**
     * 批量删除站点
     * 
     * @param ids 需要删除的站点主键
     * @return 结果
     */
    @Override
    public int deleteGSitesByIds(Long[] ids)
    {
        return gSitesMapper.deleteGSitesByIds(ids);
    }

    /**
     * 删除站点信息
     * 
     * @param id 站点主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteGSitesById(Long id)
    {
        GSiteGroups gSiteGroups =gSiteGroupsMapper.selectGSiteGroupsById(id);
        if(gSiteGroups==null){
            throw new RuntimeException("站点不存在");
        }
        int deleted= gSitesMapper.deleteById(gSiteGroups.getId());
        //删除关系
        int deleted1=gSiteGroupsMapper.deleteById(id);
        return deleted==1&&deleted1==1?1:0 ;
    }
}
